@@ -1,13 +1,13 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "epkg-marginalia" "1.1.3"
+(define-package "epkg-marginalia" "20251012.1349"
   "Show Epkg information in completion annotations."
   '((emacs      "28.1")
     (compat     "30.1")
     (epkg       "4.1")
-    (marginalia "2.9"))
+    (marginalia "2.3"))
   :url "https://github.com/emacscollective/epkg-marginalia"
-  :commit "1fda65cebc0d53319f2972ae52d182bdf5470702"
-  :revdesc "v1.1.3-0-g1fda65cebc0d"
+  :commit "7418f8e9690efa9d6821a63bf815d3b868a425ba"
+  :revdesc "7418f8e9690e"
   :keywords '("tools")
   :authors '(("Jonas Bernoulli" . "emacs.epkg-marginalia@jonas.bernoulli.dev"))
   :maintainers '(("Jonas Bernoulli" . "emacs.epkg-marginalia@jonas.bernoulli.dev")))
